:mod:`art.estimators.poison_mitigation`
=======================================
.. automodule:: art.estimators.poison_mitigation

Keras Neural Cleanse Classifier
-------------------------------
.. autoclass:: KerasNeuralCleanse
   :members:
   :special-members: __init__
   :inherited-members:

Mixin Base Class STRIP
----------------------
.. autoclass:: STRIPMixin
   :members:
   :special-members: __init__
   :inherited-members:
